@@ -139,15 +139,35 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
         }
         // line 59
         yield "            </script>
+            <script>
+                (function() {
+                    var BRAND = \"Cause Buzz\";
 
+                    function enforceBrand() {
+                        var titleEl = document.querySelector(\"title\");
+                        if (titleEl && titleEl.textContent !== BRAND) {
+                            titleEl.textContent = BRAND;
+                        }
+                    }
+
+                    // Run once
+                    enforceBrand();
+
+                    // Watch for Mautic changing title
+                    var titleEl = document.querySelector(\"title\");
+                    if (titleEl) {
+                        new MutationObserver(enforceBrand).observe(titleEl, { childList: true });
+                    }
+                })();
+            </script>
             ";
-        // line 61
+        // line 81
         yield $this->extensions['Mautic\CoreBundle\Twig\Extension\AssetExtension']->outputScripts("bodyClose");
         yield "
             ";
-        // line 62
+        // line 82
         yield Twig\Extension\CoreExtension::include($this->env, $context, "@MauticCore/Helper/modal.html.twig", ["id" => "MauticSharedModal", "footerButtons" => true]);
-        // line 65
+        // line 85
         yield "
         </section>
     </body>
@@ -193,7 +213,7 @@ array_key_exists("headerTitle", $context)) ? (Twig\Extension\CoreExtension::defa
      */
     public function getDebugInfo(): array
     {
-        return array (  168 => 40,  161 => 39,  151 => 65,  149 => 62,  145 => 61,  141 => 59,  127 => 47,  125 => 46,  119 => 42,  117 => 39,  107 => 32,  103 => 31,  93 => 24,  86 => 20,  80 => 17,  76 => 16,  72 => 15,  68 => 14,  64 => 13,  60 => 12,  55 => 10,  50 => 7,  48 => 4,  47 => 3,  43 => 1,);
+        return array (  188 => 40,  181 => 39,  171 => 85,  169 => 82,  165 => 81,  141 => 59,  127 => 47,  125 => 46,  119 => 42,  117 => 39,  107 => 32,  103 => 31,  93 => 24,  86 => 20,  80 => 17,  76 => 16,  72 => 15,  68 => 14,  64 => 13,  60 => 12,  55 => 10,  50 => 7,  48 => 4,  47 => 3,  43 => 1,);
     }
 
     public function getSourceContext(): Source
